@@ -265,13 +265,13 @@ class Chemical:
     
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner_McGraw
+    [0] Wagner McGraw
     [1] Antoine
-    [2] DIPPR_EQ101
+    [2] DIPPR EQ101
     [3] Wagner
-    [4] Boiling_Critical_Relation
-    [5] Lee_Kesler
-    [6] Ambrose_Walton
+    [4] Boiling Critical Relation
+    [5] Lee Kesler
+    [6] Ambrose Walton
     [7] Sanjari
     [8] Edalat
 
@@ -285,7 +285,7 @@ class Chemical:
     A model handle contains a series of models applicable to a certain domain:
     
     >>> Water.Psat[0].show()
-    TDependentModel: Wagner_McGraw
+    TDependentModel: Wagner McGraw
      evaluate: Wagner_McGraw(T, P=None) -> Psat [Pa]
      Tmin: 275 K
      Tmax: 647.35 K
@@ -331,14 +331,14 @@ class Chemical:
     ...     return 10.0**(10.116 -  1687.537 / (T - 42.98))
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] User_antoine_model
-    [1] Wagner_McGraw
+    [0] User antoine model
+    [1] Wagner McGraw
     [2] Antoine
-    [3] DIPPR_EQ101
+    [3] DIPPR EQ101
     [4] Wagner
-    [5] Boiling_Critical_Relation
-    [6] Lee_Kesler
-    [7] Ambrose_Walton
+    [5] Boiling Critical Relation
+    [6] Lee Kesler
+    [7] Ambrose Walton
     [8] Sanjari
     [9] Edalat
 
@@ -362,49 +362,49 @@ class Chemical:
     
     >>> # Note: In this case, we pass the model name, but its
     >>> # also possible to pass the current index, or the model itself.
-    >>> Water.Psat.move_up_model_priority('Wagner_McGraw')
+    >>> Water.Psat.move_up_model_priority('Wagner McGraw')
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner_McGraw
+    [0] Wagner McGraw
     [1] Antoine
-    [2] DIPPR_EQ101
+    [2] DIPPR EQ101
     [3] Wagner
-    [4] Boiling_Critical_Relation
-    [5] Lee_Kesler
-    [6] Ambrose_Walton
+    [4] Boiling Critical Relation
+    [5] Lee Kesler
+    [6] Ambrose Walton
     [7] Sanjari
     [8] Edalat
-    [9] User_antoine_model
+    [9] User antoine model
     
     >>> Water.Psat.set_model_priority('Antoine')
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
     [0] Antoine
-    [1] Wagner_McGraw
-    [2] DIPPR_EQ101
+    [1] Wagner McGraw
+    [2] DIPPR EQ101
     [3] Wagner
-    [4] Boiling_Critical_Relation
-    [5] Lee_Kesler
-    [6] Ambrose_Walton
+    [4] Boiling Critical Relation
+    [5] Lee Kesler
+    [6] Ambrose Walton
     [7] Sanjari
     [8] Edalat
-    [9] User_antoine_model
+    [9] User antoine model
     
     The default priority is `0` (or top priority), but you can choose any priority:
     
     >>> Water.Psat.set_model_priority('Antoine', 1)
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
-    [0] Wagner_McGraw
+    [0] Wagner McGraw
     [1] Antoine
-    [2] DIPPR_EQ101
+    [2] DIPPR EQ101
     [3] Wagner
-    [4] Boiling_Critical_Relation
-    [5] Lee_Kesler
-    [6] Ambrose_Walton
+    [4] Boiling Critical Relation
+    [5] Lee Kesler
+    [6] Ambrose Walton
     [7] Sanjari
     [8] Edalat
-    [9] User_antoine_model
+    [9] User antoine model
     
     .. note::
     
@@ -790,16 +790,16 @@ class Chemical:
         
         # Surface tension
         if Tb:
-            try:    Hvap_Tb = Hvap(Tb)
-            except: Hvap_Tb = None
-            try:    Cnl_Tb = Cn.l(Tb)
-            except: Cnl_Tb = None
-            try:    rhol = 1/V.l(Tb, 101325.) * MW
-            except: rhol = None
+            Hvap_Tb = Hvap.try_out(Tb)
+            if Hvap_Tb: Hvap_Tb /= MW
+            Cn_l = Cn.l.try_out(Tb)
+            if Cn_l: Cn_l /= MW
+            V_l = V.l.try_out(Tb, 101325.)
+            rho_l = fn.V_to_rho(V_l, MW) if V_l else None
         else:
-            Hvap_Tb = Cnl_Tb = rhol = None
+            Hvap_Tb = Cn_l = rho_l = None
         data = (CAS, MW, Tb, Tc, Pc, Vc, Zc,
-                omega, self.Stiel_Polar, Hvap_Tb, rhol, Cnl_Tb)
+                omega, self.Stiel_Polar, Hvap_Tb, rho_l, Cn_l)
         self.sigma = surface_tension_handle(data)
         
         # Other
