@@ -58,7 +58,7 @@ def functor_base_and_params(function):
 
 # %% Decorator
   
-def functor(f=None, var=None, wrap=None, **autodoc):
+def functor(f=None, var=None, **autodoc):
     """
     Decorate a function of temperature, or both temperature and pressure as a Functor subclass.
     
@@ -108,12 +108,11 @@ def functor(f=None, var=None, wrap=None, **autodoc):
                'var': var}
         cls = type(f.__name__, (base,), dct)
         cls._autodoc_ = autodoc
-        if wrap: cls.wrapper(wrap, **autodoc)
-        elif autodoc: autodoc_functor(cls, **autodoc)
+        if autodoc: autodoc_functor(cls, **autodoc)
         cls.__module__ = f.__module__
         return cls
     else:
-        return lambda f: functor(f, var, wrap, **autodoc)
+        return lambda f: functor(f, var, **autodoc)
 
 
 # %% Decorators
@@ -124,17 +123,17 @@ class FunctorFactory:
     def __init__(self, var):
         self.var = var
     
-    def __call__(self, function=None, wrap=None, **autodoc):
-        return functor(function, self.var, wrap, **autodoc)
+    def __call__(self, function=None, **autodoc):
+        return functor(function, self.var, **autodoc)
     
-    def s(self, function=None, wrap=None, **autodoc):
-        return functor(function, self.var + '.s', wrap, **autodoc)
+    def s(self, function=None, **autodoc):
+        return functor(function, self.var + '.s', **autodoc)
     
-    def l(self, function=None, wrap=None, **autodoc):
-        return functor(function, self.var + '.l',  wrap, **autodoc)
+    def l(self, function=None, **autodoc):
+        return functor(function, self.var + '.l',  **autodoc)
     
-    def g(self, function=None, wrap=None, **autodoc):
-        return functor(function, self.var + '.g', wrap, **autodoc)
+    def g(self, function=None, **autodoc):
+        return functor(function, self.var + '.g', **autodoc)
     
     def __repr__(self):
         return f"{type(self).__name__}({repr(self.var)})"
