@@ -120,7 +120,7 @@ class ThermoModel:
                  Pmin=None, Pmax=None,
                  name=None, var=None, **funcs):
         self.var = var or evaluate.var
-        self.name = name or functor_name(evaluate)
+        self.name = name or functor_name(evaluate).replace('_', ' ')
         self.evaluate = evaluate
         self.__dict__.update(funcs)
         if Pmin: self.Pmin = Pmin
