@@ -305,9 +305,10 @@ definitions = {'MW': 'Molecular weight',
                'similarity_variable': 'Heat capacity similarity variable',
                'iscyclic_aliphatic': 'Whether a chemical is cyclic aliphatic',
                'has_hydroxyl': 'Whether a polar chemical has hydroxyl groups',
+               'atoms': 'Atom-count pairs'
 }
 
-types = {}
+types = {'atoms': 'Dict[str, int]'}
 types['iscyclic_aliphatic'] = types['has_hydroxy'] = 'bool'
 
 # Synonyms
