@@ -52,10 +52,10 @@ class BubblePoint:
     >>> # Solve bubble point at constant temperature
     >>> bp = BP(z=molar_composition, T=355)
     >>> bp
-    BubblePointValues(T=355, P=109755.45319868933, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
+    BubblePointValues(T=355, P=109755.45319869413, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
     >>> # Note that the result is a BubblePointValues object which contain all results as attibutes
     >>> (bp.T, bp.P, bp.IDs, bp.z, bp.y)
-    (355, 109755.45319868933, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
+    (355, 109755.45319869413, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
     >>> # Solve bubble point at constant pressure
     >>> BP(z=molar_composition, P=101325)
     BubblePointValues(T=352.95030269946596, P=101325, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.342 0.658])
@@ -108,7 +108,8 @@ class BubblePoint:
         return BubblePointValues(T, P, self.IDs, z, y)
     
     def solve_Ty(self, z, P):
-        """Bubble point at given composition and pressure
+        """
+        Bubble point at given composition and pressure
 
         Parameters
         ----------
@@ -138,11 +139,11 @@ class BubblePoint:
         z = asarray(z)
         z_norm = z / z.sum()
         self.P = P
-        args = (P, z/P, z_norm)
+        args = (P, z_norm/P, z_norm)
         T = self.T or (z * self.Tbs).sum()
         try:
             self.T = self.rootsolver(self._T_error, T, T+0.01,
-                                     1e-6, 5e-8, args)
+                                     1e-6, 5e-9, args)
         except:
             self.y = z.copy()
             T = (z * self.Tbs).sum()
@@ -152,12 +153,13 @@ class BubblePoint:
             if Tmin < 10: Tmin = 10
             self.T = IQ_interpolation(f, Tmin, Tmax,
                                       f(Tmin), f(Tmax),
-                                      T, 0., 1e-6, 5e-8)
+                                      T, 0., 1e-6, 5e-9)
         self.y = normalize(self.y)
         return self.T, self.y.copy()
     
     def solve_Py(self, z, T):
-        """Bubble point at given composition and temperature.
+        """
+        Bubble point at given composition and temperature.
 
         Parameters
         ----------
@@ -180,7 +182,7 @@ class BubblePoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
         >>> BP.solve_Py(z=(0.703, 0.297), T=352.28)
-        (91830.9798895792, array([0.419, 0.581]))
+        (91830.9798895787, array([0.419, 0.581]))
         
         """
         z = asarray(z)
@@ -192,11 +194,11 @@ class BubblePoint:
         P = self.P or (z * Psat).sum()
         try:
             self.P = self.rootsolver(self._P_error, P, P-1,
-                                     1e-2, 5e-8, args)
+                                     1e-3, 1e-9, args)
         except:
             P = (z * Psat).sum()
             self.P = self.rootsolver(self._P_error, P, P-1,
-                                     1e-2, 5e-8, args)
+                                     1e-3, 5e-9, args)
         self.y = normalize(self.y)
         return self.P, self.y.copy()
     
