@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 """
-Created on Wed Nov 27 19:11:28 2019
+Functional utilities for the calculation of thermodynamic properties.
 
-@author: yoelr
 """
 from fluids.core import thermal_diffusivity
 from cmath import sqrt as csqrt
