@@ -46,7 +46,9 @@ def get_combustion_stoichiometry(atoms: dict,
     The stoichiometry is given by:
         
     .. math::
-        C_c H_h O_o N_n S_s Br_b I_i Cl_x F_f P_p + (c + s + \frac{h}{4} + \frac{5P}{4} - \frac{x + f}{4} - \frac{o}{2}) -> cCO_2 + \frac{b}{2}Br_2 + \frac{i}{2}I + xHCl + fHF + sSO_2 + \frac{n}{2}N_2 + \frac{p}{4}P_4O_{10} +\frac{h + x + f}{2}H_2O
+        C_c H_h O_o N_n S_s Br_b I_i Cl_x F_f P_p + kO_2 -> cCO_2 + \frac{b}{2}Br_2 + \frac{i}{2}I + xHCl + fHF + sSO_2 + \frac{n}{2}N_2 + \frac{p}{4}P_4O_{10} +\frac{h + x + f}{2}H_2O
+
+        k = c + s + \frac{h}{4} + \frac{5P}{4} - \frac{x + f}{4} - \frac{o}{2}
 
     """
     combustion_atoms = {i:atoms.get(i, 0) for i in combustible_elements}
@@ -180,7 +182,9 @@ class CombustionData:
         combustion reaction is based on the following equation:
         
         .. math::
-            C_c H_h O_o N_n S_s Br_b I_i Cl_x F_f P_p + (c + s + \frac{h}{4} + \frac{5P}{4} - \frac{x + f}{4} - \frac{o}{2}) -> cCO_2 + \frac{b}{2}Br_2 + \frac{i}{2}I + xHCl + fHF + sSO_2 + \frac{n}{2}N_2 + \frac{p}{4}P_4O_{10} +\frac{h + x + f}{2}H_2O
+            C_c H_h O_o N_n S_s Br_b I_i Cl_x F_f P_p + kO_2 -> cCO_2 + \frac{b}{2}Br_2 + \frac{i}{2}I + xHCl + fHF + sSO_2 + \frac{n}{2}N_2 + \frac{p}{4}P_4O_{10} +\frac{h + x + f}{2}H_2O
+            
+            k = c + s + \frac{h}{4} + \frac{5P}{4} - \frac{x + f}{4} - \frac{o}{2}
     
         If the method is "Stoichiometry", the HHV is found using 
         through an energy balance on the reaction (i.e. heat of reaction).
@@ -193,7 +197,9 @@ class CombustionData:
             
         .. math::
             LHV = HHV + H_{vap} \cdot H_2O
+            
             H_{vap} = 44011.496 \frac{J}{mol H_2O}
+            
             H_2O = \frac{mol H_2O}{mol}
             
             
