@@ -31,13 +31,12 @@ References
 .. [9] Green, Don, and Robert Perry.
        Perry's Chemical Engineers' Handbook,
        Eighth Edition. McGraw-Hill Professional, 2007.
-       
+
 """
 import os
 from io import open
 from math import log, exp
 from cmath import log as clog, exp as cexp
-from ..utils import njitable
 import numpy as np
 from ..base import InterpolatedTDependentModel, thermo_model, TDependentHandleBuilder, \
                    PhaseTPropertyBuilder, S, H, Cn
@@ -168,7 +167,7 @@ with open(os.path.join(read.folder, 'Perrys Table 2-151.tsv'), encoding='utf-8')
 
 
 # %% Heat Capacities Gas
-@njitable
+ 
 def calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similary_variable):
     if iscyclic_aliphatic:
         A1 = -0.1793547
@@ -198,9 +197,15 @@ def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
 
     Original model is in terms of J/g/K, but is translated to molar heat capacity in J/mol/K.
 
-    A1 = 0.58, A2 = 1.25, A3 = 0.17338003, A4 = 0.014, B11 = 0.73917383,
-    B12 = 8.88308889, C11 = 1188.28051, C12 = 1813.04613, B21 = 0.0483019,
-    B22 = 4.35656721, C21 = 2897.01927, C22 = 5987.80407.
+    A1 = 0.58, A2 = 1.25, A3 = 0.17338003, A4 = 0.014,
+    
+    B11 = 0.73917383, B12 = 8.88308889,
+    
+    C11 = 1188.28051, C12 = 1813.04613,
+    
+    B21 = 0.0483019, B22 = 4.35656721, 
+    
+    C21 = 2897.01927, C22 = 5987.80407.
 
     Examples
     --------
@@ -238,7 +243,7 @@ def Lastovka_Shaw_Integral(Ta, Tb, MW, similarity_variable, iscyclic_aliphatic=F
     return (Lastovka_Shat_Indefinite_Integral(Tb, MW, similarity_variable, term)
             - Lastovka_Shat_Indefinite_Integral(Ta, MW, similarity_variable, term))
 
-@njitable
+ 
 def Lastovka_Shat_Indefinite_Integral(T, MW, similarity_variable, term=None):
     a = similarity_variable
     B11 = 0.73917383
@@ -260,7 +265,7 @@ def Lastovka_Shaw_Integral_Over_T(Ta, Tb, MW, similarity_variable,
     return (Lastovka_Shaw_Indefinite_Integral_Over_T(Tb, MW, similarity_variable, term)
             - Lastovka_Shaw_Indefinite_Integral_Over_T(Ta, MW, similarity_variable, term))
 
-@njitable
+ 
 def Lastovka_Shaw_Indefinite_Integral_Over_T(T, MW, similarity_variable, term):
     a = similarity_variable
     a2 = a*a
@@ -322,7 +327,7 @@ def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
         y = (T - a7)/(T + a6)
     return R*(a0 + (a1/T**2)*exp(-a2/T) + a3*y**2 + (a4 - a5/(T-a7)**2 )*y**8.)
 
-@njitable
+ 
 def TRCCn_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
     first = a6 + a7    
     y = 0. if T <= a7 else (T - a7)/(T + a6)
@@ -343,7 +348,7 @@ def TRCCn_Integral(Ta, Tb, a0, a1, a2, a3, a4, a5, a6, a7):
     return (TRCCn_Indefinite_Integral(Tb, a0, a1, a2, a3, a4, a5, a6, a7)
             - TRCCn_Indefinite_Integral(Ta, a0, a1, a2, a3, a4, a5, a6, a7))
 
-@njitable
+ 
 def TRCCn_Over_T_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
     # Possible optimizations: pre-cache as much as possible.
     # If this were replaced by a cache, much of this would not need to be computed.
@@ -399,7 +404,7 @@ def Poling(T, a, b, c, d, e):
     """
     return R*(a + b*T + c*T**2 + d*T**3 + e*T**4)
 
-@njitable
+ 
 def Poling_Indefinite_Integral(T, a, b, c, d, e):
     return (((((0.2*e)*T + 0.25*d)*T + c/3.)*T + 0.5*b)*T + a)*T
 
@@ -408,7 +413,7 @@ def Poling_Integral(Ta, Tb, a, b, c, d, e):
     return R*(Poling_Indefinite_Integral(Tb, a, b, c, d, e)
               - Poling_Indefinite_Integral(Ta, a, b, c, d, e))
 
-@njitable
+ 
 def Poling_Over_T_Indefinite_Integral(T, a, b, c, d, e):
     return ((((0.25*e)*T + d/3.)*T + 0.5*c)*T + b)*T
 
@@ -539,6 +544,7 @@ def Dadgostar_Shaw(T, MW, similarity_variable):
     .. math::
         C_{p} = 24.5(a_{11}\alpha + a_{12}\alpha^2)+ (a_{21}\alpha
         + a_{22}\alpha^2)T +(a_{31}\alpha + a_{32}\alpha^2)T^2
+        
         C_n = MW \cdot Cp
 
     Where :math:`\alpha` is the similarity variable. There are many restrictions on its use.
@@ -553,7 +559,7 @@ def Dadgostar_Shaw(T, MW, similarity_variable):
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return (first + second*T + third*T**2) * MW
 
-@njitable
+ 
 def calculate_Dadgostar_Shaw_terms(MW, similarity_variable):
     a = similarity_variable
     a2 = a*a
@@ -570,7 +576,7 @@ def calculate_Dadgostar_Shaw_terms(MW, similarity_variable):
             a21*a + a22*a2,
             a31*a + a32*a2)
 
-@njitable
+ 
 def Dadgostar_Shaw_Indefinte_Integral(T, first, second, third):
     T2 = T*T
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
@@ -582,7 +588,7 @@ def Dadgostar_Shaw_Integral(Ta, Tb, MW, similarity_variable):
     return MW*(Dadgostar_Shaw_Indefinte_Integral(Tb, *terms)
                - Dadgostar_Shaw_Indefinte_Integral(Ta, *terms))
 
-@njitable
+ 
 def Dadgostar_Shaw_Over_T_Indefinte_Integral(T, first, second, third):
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return T*T*0.5*third + T*second + first*log(T)
@@ -647,7 +653,7 @@ def Zabransky_Quasi_Polynomial(T, Tc, a1, a2, a3, a4, a5, a6):
     Tr = T/Tc
     return R*(a1*log(1-Tr) + a2/(1-Tr) + a3 + a4*Tr + a5*Tr**2 + a6*Tr**3)
 
-@njitable
+ 
 def Zabransky_Quasi_Polynomial_Indefinte_Integral(T, Tc, a1, a2, a3, a4, a5, a6):
     Tc2 = Tc*Tc
     Tc3 = Tc2*Tc    
@@ -660,7 +666,6 @@ def Zabransky_Quasi_Polynomial_Integral(Ta, Tb, Tc, a1, a2, a3, a4, a5, a6):
     return (Zabransky_Quasi_Polynomial_Indefinte_Integral(Tb, Tc, a1, a2, a3, a4, a5, a6)
             - Zabransky_Quasi_Polynomial_Indefinte_Integral(Ta, Tc, a1, a2, a3, a4, a5, a6))
 
-@njitable
 def Zabransky_Quasi_Polynomial_Over_T_Indefinte_Integral(T, Tc, a1, a2, a3, a4, a5, a6):
     Tc2 = Tc*Tc
     Tc3 = Tc2*Tc    
@@ -689,7 +694,7 @@ def Zabransky_Cubic(T, a1, a2, a3, a4):
     T = T/100.
     return R*(((a4*T + a3)*T + a2)*T + a1)
 
-@njitable
+ 
 def Zabransky_Cubic_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return 100.*R*T*(T*(T*(T*a4*0.25 + a3/3.) + a2*0.5) + a1)
@@ -699,7 +704,7 @@ def Zabransky_Cubic_Integral(Ta, Tb, a1, a2, a3, a4):
     return (Zabransky_Cubic_Indefinite_Integral(Tb, a1, a2, a3, a4)
             - Zabransky_Cubic_Indefinite_Integral(Ta, a1, a2, a3, a4))
 
-@njitable
+ 
 def Zabransky_Cubic_Over_T_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return R*(T*(T*(T*a4/3. + a3/2.) + a2) + a1*log(T))
@@ -840,7 +845,7 @@ def Lastovka_Solid(T, similarity_variable, MW):
                  + (C1*similarity_variable + C2*sim2)*T
                  + (D1*similarity_variable + D2*sim2)*T**2)
 
-@njitable
+ 
 def Lastovka_Solid_Indefinite_Integral(T, similarity_variable, MW):
     A1 = 0.013183
     A2 = 0.249381
@@ -861,7 +866,7 @@ def Lastovka_Solid_Integral(Ta, Tb, similarity_variable, MW):
     return (Lastovka_Solid_Indefinite_Integral(Tb, similarity_variable, MW)
             - Lastovka_Solid_Indefinite_Integral(Ta, similarity_variable, MW))
 
-@njitable
+ 
 def Lastovka_Solid_Over_T_Indefinite_Integral(T, similarity_variable, MW):
     A1 = 0.013183
     A2 = 0.249381
@@ -944,4 +949,3 @@ def heat_capacity_solid_handle(handle, CAS, similarity_variable, MW):
                   name=LASTOVKA_S)
 
 heat_capacity_handle = PhaseTPropertyBuilder('Cn', heat_capacity_solid_handle, heat_capacity_liquid_handle, heat_capacity_gas_handle)
-
