@@ -42,6 +42,7 @@ References
         Richard L. Rowley. "A Note on the Relationship between Organic Solid
         Density and Liquid Density at the Triple Point." Journal of Chemical &
         Engineering Data 49, no. 6 (2004): 1512-14. doi:10.1021/je034220e.
+
 """
 import numpy as np
 from scipy.interpolate import interp1d
@@ -53,7 +54,9 @@ from .virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BV
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ105
 # from .electrochem import _Laliberte_Density_ParametersDict, Laliberte_Density
-from ..base import V, InterpolatedTDependentModel, TPDependentModel, TPDependentHandleBuilder, PhaseTPPropertyBuilder
+from ..base import (V, InterpolatedTDependentModel, 
+                    TPDependentModel, TPDependentHandleBuilder,
+                    PhaseTPPropertyBuilder, ThermoModelHandle)
 
 __all__ = ('volume_handle',
            'Yen_Woods',
@@ -345,7 +348,7 @@ def Costald(T, Tc, Vc, omega):
         - 0.81446*(1-Tr) + 0.190454*(1-Tr)**(4/3.)
     return Vc*V_0*(1-omega*V_delta)
 
-@V.l(ref='[8]_', equation='Campbell-Thodos CSP')
+@V.l(ref='[8]_', method='Campbell-Thodos CSP')
 def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     r'''
     Notes
@@ -424,7 +427,7 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     Vs = R*Tc/(Pc*101325)*Zra**(1+(1-Tr)**(2./7.))
     return Vs
 
-@V.l(equation='Mchaweh-Moshfeghian', ref='[9]_')
+@V.l(method='Mchaweh-Moshfeghian', ref='[9]_')
 def SNM0(T, Tc, Vc, omega, delta_SRK):
     r'''
     Notes
@@ -521,23 +524,9 @@ def VDI_PPDS(T, Tc, rhoc, MW, a, b, c, d):
     rho = rhoc + a*tau**0.35 + b*tau**(2/3.) + c*tau + d*tau**(4/3.)
     return fn.rho_to_V(rho, MW)
    
-@V.l(ref="[11]_", doc="auto-header")
-def Costald_Compressed(T, P, Psat, Tc, Pc, omega, Vs):
+@V.l(ref="[11]_")
+def Costald_Compressed(T, P, Psat, Tc, Pc, omega, V):
     r'''
-    Parameters
-    ----------
-    Psat : function(T)
-        Should return saturation pressure of the fluid [Pa]
-    Tc : float
-        Critical temperature of fluid [K]
-    Pc : float
-        Critical pressure of fluid [Pa]
-    omega : float
-        (ideally SRK) Acentric factor for fluid, [-]
-        This parameter is alternatively a fit parameter.
-    Vs : function(T, P)
-        Should return saturation liquid volume, [m^3/mol]
-    
     Notes
     -----
     The molar volume of a liquid is given by:
@@ -576,7 +565,9 @@ def Costald_Compressed(T, P, Psat, Tc, Pc, omega, Vs):
     C = j + k*omega
     tau = 1 - T/Tc
     B = Pc*(-1 + a*tau**(1/3.) + b*tau**(2/3.) + d*tau + e*tau**(4/3.))
-    return Vs(T, P)*(1 - C*log((B + P)/(B + Psat(T))))
+    if isinstance(Psat, ThermoModelHandle): Psat = Psat.at_T(T)
+    if isinstance(V, ThermoModelHandle): V = V.at_T(T)
+    return V*(1 - C*log((B + P)/(B + Psat)))
 
 @TPDependentHandleBuilder('V.l')
 def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
@@ -639,7 +630,7 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
         add_model(Campbell_Thodos.from_args(data), 0, Tc, top_priority=top_priority)
     data = (Tc, Pc, omega)
     if all_(data):
-        data = (Psat, Tc, Pc, omega, handle.copy())
+        data = (Psat, Tc, Pc, omega, handle)
         add_model(Costald_Compressed.from_args(data), 50, 500)
         
 
@@ -729,4 +720,3 @@ volume_handle = PhaseTPPropertyBuilder('V',
                                        volume_liquid_handle,
                                        volume_gas_handle)
 
-
